@@ -14,10 +14,21 @@ class DepthShader : public Shader {
     float m_waterLevel;
     float m_murkyDepth;
   public:
-    explicit DepthShader(float waterLevel = 0.f, float murkyDepth = -64.f);
+    static const std::string key_waterLevel;
+    static const std::string key_murkyDepth;
+
+    static const float default_waterLevel;
+    static const float default_murkyDepth;
+
+    explicit DepthShader(float waterLevel = default_waterLevel,
+                         float murkyDepth = default_murkyDepth);
+    explicit DepthShader(const Parameters & params);
     virtual ~DepthShader();
 
-    virtual bool checkIntersect(Surface &) const;
+    const float waterLevel() const { return m_waterLevel; }
+    const float murkyDepth() const { return m_murkyDepth; }
+
+    virtual bool checkIntersect(const Segment &) const;
     virtual void shade(Surface &) const;
 };
 
