@@ -12,9 +12,10 @@ namespace Mercator {
 class FillShader : public Shader {
   public:
     explicit FillShader();
+    explicit FillShader(const Parameters & params);
     virtual ~FillShader();
 
-    virtual bool checkIntersect(Surface &) const;
+    virtual bool checkIntersect(const Segment &) const;
     virtual void shade(Surface &) const;
 };
 
