@@ -5,11 +5,12 @@
 #include <Mercator/Surface.h>
 
 #include <Mercator/Shader.h>
+#include <cassert>
 
 namespace Mercator {
 
-Surface::Surface(Segment & seg, const Shader & sh, bool color, bool alpha) :
-    Buffer<ColorT>(seg, (color ? 3 : 0) + (alpha ? 1 : 0)), m_shader(sh)
+Surface::Surface(const Segment & seg, const Shader & sh, bool color, bool alpha)
+  : Buffer<ColorT>(seg, (color ? 3 : 0) + (alpha ? 1 : 0)), m_shader(sh)
 {
 }
 
@@ -22,9 +23,9 @@ void Surface::populate()
     if (!isValid()) {
         allocate();
     }
-    if (m_shader.checkIntersect(*this)) {
-        m_shader.shade(*this);
-    }
+
+    assert(m_shader.checkIntersect(m_segment));
+    m_shader.shade(*this);
 }
 
 } // namespace Mercator
